@@ -1,5 +1,3 @@
-/* $Xorg: XChgKMap.c,v 1.4 2001/02/09 02:03:50 xorgcvs Exp $ */
-
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -45,7 +43,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/Xi/XChgKMap.c,v 3.3 2001/12/14 19:55:04 dawes Exp $ */
 
 /***********************************************************************
  *
@@ -53,6 +50,10 @@ SOFTWARE.
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XIproto.h>
 #include <X11/Xlibint.h>
@@ -61,13 +62,13 @@ SOFTWARE.
 #include "XIint.h"
 
 int
-XChangeDeviceKeyMapping(dpy, dev, first, syms_per_code, keysyms, count)
-    register Display *dpy;
-    XDevice *dev;
-    int first;
-    int syms_per_code;
-    KeySym *keysyms;
-    int count;
+XChangeDeviceKeyMapping(
+    register Display	*dpy,
+    XDevice		*dev,
+    int			 first,
+    int			 syms_per_code,
+    KeySym		*keysyms,
+    int			 count)
 {
     register long nbytes;
     xChangeDeviceKeyMappingReq *req;
