@@ -1,5 +1,3 @@
-/* $Xorg: XSelect.c,v 1.4 2001/02/09 02:03:51 xorgcvs Exp $ */
-
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -45,13 +43,15 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/Xi/XSelect.c,v 3.3 2001/12/14 19:55:21 dawes Exp $ */
 
 /***********************************************************************
  *
  * XSelectExtensionEvent - Select input from an extension device.
  *
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XIproto.h>
@@ -61,11 +61,11 @@ SOFTWARE.
 #include "XIint.h"
 
 int
-XSelectExtensionEvent(dpy, w, event_list, count)
-    register Display *dpy;
-    Window w;
-    XEventClass *event_list;
-    int count;
+XSelectExtensionEvent(
+    register Display	*dpy,
+    Window		 w,
+    XEventClass		*event_list,
+    int			 count)
 {
     register xSelectExtensionEventReq *req;
     XExtDisplayInfo *info = XInput_find_display(dpy);
